==> DAAG_0.34.tar.gz: DAAG/data/ozone.R <==
"ozone" <-
structure(list(Year = c(1956, 1957, 1958, 1959, 1960, 1961, 1962, 
1963, 1964, 1965, 1966, 1967, 1968, 1969, 1970, 1971, 1972, 1973, 
1974, 1975, 1976, 1977, 1978, 1979, 1980, 1981, 1982, 1983, 1984, 
1985, 1986, 1987, 1988, 1989, 1990, 1991, 1992, 1993, 1994, 1995, 
1996, 1997, 1998, 1999, 2000), Aug = c(0, 301, 0, 0, 0, 0, 0, 
313, 271, 0, 0, 0, 284, 0, 307, 0, 304, 272, 0, 0, 0, 290, 0, 
0, 328, 0, 0, 0, 0, 0, 253, 254, 242, 270, 259, 204, 185, 209, 
197, 218, 173, 218, 221, 205, 179), Sep = c(313, 284, 0, 0, 287, 
267, 0, 0, 0, 0, 288, 0, 279, 285, 0, 278, 265, 263, 244, 267, 
265, 239, 264, 232, 236, 241, 210, 228, 215, 217, 212, 182, 207, 
186, 173, 163, 152, 167, 152, 160, 155, 171, 162, 172, 151), 
    Oct = c(311, 320, 305, 302, 292, 307, 322, 300, 308, 273, 
    307, 313, 292, 274, 274, 290, 295, 271, 272, 303, 283, 251, 
    284, 263, 226, 237, 218, 195, 194, 185, 233, 150, 216, 150, 
    173, 137, 147, 122, 126, 130, 148, 141, 140, 143, 137), Nov = c(370, 
    394, 349, 303, 345, 332, 380, 347, 401, 298, 338, 357, 385, 
    297, 355, 373, 375, 326, 337, 309, 326, 332, 345, 323, 293, 
    285, 268, 289, 248, 215, 282, 188, 312, 255, 207, 232, 206, 
    179, 217, 164, 181, 210, 183, 172, 267), Dec = c(359, 347, 
    378, 340, 375, 343, 376, 350, 356, 335, 344, 333, 348, 314, 
    344, 344, 349, 334, 351, 338, 335, 360, 337, 352, 340, 326, 
    322, 325, 322, 304, 309, 287, 323, 295, 246, 296, 270, 285, 
    316, 252, 260, 286, 255, 254, 299), Jan = c(334, 332, 341, 
    322, 318, 310, 319, 316, 314, 299, 299, 318, 311, 305, 317, 
    315, 306, 307, 320, 314, 318, 310, 295, 324, 299, 290, 308, 
    301, 301, 286, 301, 286, 284, 290, 281, 271, 284, 278, 278, 
    261, 278, 267, 272, 281, 286), Feb = c(296, 301, 328, 298, 
    303, 297, 302, 300, 294, 289, 284, 285, 290, 285, 312, 300, 
    293, 275, 275, 272, 280, 305, 283, 292, 280, 278, 292, 272, 
    269, 273, 278, 264, 281, 266, 257, 283, 275, 264, 269, 249, 
    265, 262, 259, 258, 261), Mar = c(288, 280, 297, 295, 304, 
    329, 305, 325, 296, 283, 268, 289, 280, 268, 274, 300, 286, 
    262, 279, 257, 275, 282, 278, 290, 253, 260, 278, 273, 263, 
    247, 274, 271, 260, 254, 263, 281, 277, 255, 256, 246, 247, 
    264, 254, 250, 251), Apr = c(274, 256, 0, 0, 0, 0, 287, 303, 
    0, 286, 0, 279, 244, 258, 277, 312, 277, 242, 0, 0, 253, 
    253, 283, 0, 0, 0, 266, 267, 245, 227, 274, 265, 274, 254, 
    233, 257, 256, 284, 254, 226, 243, 255, 267, 256, 245), Year = c(318, 
    312, 333, 309, 318, 312, 327, 319, 320, 295, 304, 310, 302, 
    286, 307, 314, 306, 292, 301, 298, 300, 302, 301, 303, 280, 
    278, 276, 270, 260, 247, 272, 235, 270, 246, 231, 239, 233, 
    225, 232, 212, 217, 230, 224, 221, 231)), .Names = c("Year", 
"Aug", "Sep", "Oct", "Nov", "Dec", "Jan", "Feb", "Mar", "Apr", 
"Year"), class = "data.frame", row.names = c("1", "2", "3", "4", 
"5", "6", "7", "8", "9", "10", "11", "12", "13", "14", "15", 
"16", "17", "18", "19", "20", "21", "22", "23", "24", "25", "26", 
"27", "28", "29", "30", "31", "32", "33", "34", "35", "36", "37", 
"38", "39", "40", "41", "42", "43", "44", "45"))

==> DAAG_0.84.tar.gz: DAAG/data/ozone.R <==
"ozone" <-
structure(list(Year = c(1956, 1957, 1958, 1959, 1960, 1961, 1962, 
1963, 1964, 1965, 1966, 1967, 1968, 1969, 1970, 1971, 1972, 1973, 
1974, 1975, 1976, 1977, 1978, 1979, 1980, 1981, 1982, 1983, 1984, 
1985, 1986, 1987, 1988, 1989, 1990, 1991, 1992, 1993, 1994, 1995, 
1996, 1997, 1998, 1999, 2000), Aug = c(0, 301, 0, 0, 0, 0, 0, 
313, 271, 0, 0, 0, 284, 0, 307, 0, 304, 272, 0, 0, 0, 290, 0, 
0, 328, 0, 0, 0, 0, 0, 253, 254, 242, 270, 259, 204, 185, 209, 
197, 218, 173, 218, 221, 205, 179), Sep = c(313, 284, 0, 0, 287, 
267, 0, 0, 0, 0, 288, 0, 279, 285, 0, 278, 265, 263, 244, 267, 
265, 239, 264, 232, 236, 241, 210, 228, 215, 217, 212, 182, 207, 
186, 173, 163, 152, 167, 152, 160, 155, 171, 162, 172, 151), 
    Oct = c(311, 320, 305, 302, 292, 307, 322, 300, 308, 273, 
    307, 313, 292, 274, 274, 290, 295, 271, 272, 303, 283, 251, 
    284, 263, 226, 237, 218, 195, 194, 185, 233, 150, 216, 150, 
    173, 137, 147, 122, 126, 130, 148, 141, 140, 143, 137), Nov = c(370, 
    394, 349, 303, 345, 332, 380, 347, 401, 298, 338, 357, 385, 
    297, 355, 373, 375, 326, 337, 309, 326, 332, 345, 323, 293, 
    285, 268, 289, 248, 215, 282, 188, 312, 255, 207, 232, 206, 
    179, 217, 164, 181, 210, 183, 172, 267), Dec = c(359, 347, 
    378, 340, 375, 343, 376, 350, 356, 335, 344, 333, 348, 314, 
    344, 344, 349, 334, 351, 338, 335, 360, 337, 352, 340, 326, 
    322, 325, 322, 304, 309, 287, 323, 295, 246, 296, 270, 285, 
    316, 252, 260, 286, 255, 254, 299), Jan = c(334, 332, 341, 
    322, 318, 310, 319, 316, 314, 299, 299, 318, 311, 305, 317, 
    315, 306, 307, 320, 314, 318, 310, 295, 324, 299, 290, 308, 
    301, 301, 286, 301, 286, 284, 290, 281, 271, 284, 278, 278, 
    261, 278, 267, 272, 281, 286), Feb = c(296, 301, 328, 298, 
    303, 297, 302, 300, 294, 289, 284, 285, 290, 285, 312, 300, 
    293, 275, 275, 272, 280, 305, 283, 292, 280, 278, 292, 272, 
    269, 273, 278, 264, 281, 266, 257, 283, 275, 264, 269, 249, 
    265, 262, 259, 258, 261), Mar = c(288, 280, 297, 295, 304, 
    329, 305, 325, 296, 283, 268, 289, 280, 268, 274, 300, 286, 
    262, 279, 257, 275, 282, 278, 290, 253, 260, 278, 273, 263, 
    247, 274, 271, 260, 254, 263, 281, 277, 255, 256, 246, 247, 
    264, 254, 250, 251), Apr = c(274, 256, 0, 0, 0, 0, 287, 303, 
    0, 286, 0, 279, 244, 258, 277, 312, 277, 242, 0, 0, 253, 
    253, 283, 0, 0, 0, 266, 267, 245, 227, 274, 265, 274, 254, 
    233, 257, 256, 284, 254, 226, 243, 255, 267, 256, 245), Annual = 
c(318, 
    312, 333, 309, 318, 312, 327, 319, 320, 295, 304, 310, 302, 
    286, 307, 314, 306, 292, 301, 298, 300, 302, 301, 303, 280, 
    278, 276, 270, 260, 247, 272, 235, 270, 246, 231, 239, 233, 
    225, 232, 212, 217, 230, 224, 221, 231)), .Names = c("Year", 
"Aug", "Sep", "Oct", "Nov", "Dec", "Jan", "Feb", "Mar", "Apr", 
"Annual"), class = "data.frame", row.names = c("1", "2", "3", "4", 
"5", "6", "7", "8", "9", "10", "11", "12", "13", "14", "15", 
"16", "17", "18", "19", "20", "21", "22", "23", "24", "25", "26", 
"27", "28", "29", "30", "31", "32", "33", "34", "35", "36", "37", 
"38", "39", "40", "41", "42", "43", "44", "45"))
